//
//  DataQueue.h
//  CommonUtils
//
//  Created by 丸山 隆夫 on 2014/12/10.
//  Copyright (c) 2014年 Sky Co., LTD. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 * @brief   バイナリデータ用のキュー
 */
@interface DataQueue : NSObject {
@protected
    NSMutableData* _queue;  // バイナリデータを格納する
    NSUInteger _length;     // _queueに含まれているデータの長さ
@private
    NSUInteger _maxSize;    // _queueが確保する最大サイズ（超えるデータを入れる事は可能）
    NSString* _name;        // このオブジェクトの名前（デバッグログで使用される）
}
@property(assign, readwrite) NSUInteger maxSize;
@property(retain, readwrite) NSString* name;

/**
 * @brief   初期化処理
 */
- (id)init;

/**
 * @brief   データをキューへ追加する
 * @param   [in]    data    追加するデータ
 */
- (void)pushData:(NSData*)data;

/**
 * @brief   データをキューから取り出す
 * @param   [in]    length  取り出すデータ長
 * @return  取り出したデータ（キューに含まれているデータ長がlengthに満たなければnil）
 */
- (NSData*)popDataWithLength:(NSUInteger)length;

/**
 * @brief   キューに含まれているデータを返す
 *          キューからデータは削除されない
 * @return  キューに含まれているデータ
 */
- (NSData*)data;

@end
