/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */

#import <Foundation/Foundation.h>

/**
 * プロセス間通信のデータを表します。
 * @since   SKYSEA8.0
 * @author  Morio Tanioku
 * @date    2012/10/11
 */
@interface MessagingPacket : NSObject<NSCoding> {
    int32_t _sequenceID;    /**< シーケンスID */
    pid_t   _pid;           /**< 送信元のプロセスID */
}

@property(assign, readwrite) int32_t sequenceID;
@property(assign, readwrite) pid_t pid;

/**
 * 初期化します。
 * @param   [in]    seqID   シーケンスID
 * @return  自身を返します。
 */
- (id)initWithSequenceID:(int32_t)seqID;

/**
 * シリアライズされたデータから初期化します。
 * @param   [in]    aDecoder    シリアライズされたデータ
 * @return  自身を返します。
 */
- (id)initWithCoder:(NSCoder*)aDecoder;

/**
 * 内容をシリアライズします。
 * @param   [in]    aCoder  シリアライズしたデータの書き込み先
 */
- (void)encodeWithCoder:(NSCoder*)aCoder;

@end

/**
 * プロセス間通信データの先頭ブロックを表します。
 * @since   SKYSEA8.0
 * @author  Morio Tanioku
 * @date    2012/10/11
 */
@interface MessagingFirstData : MessagingPacket {
    int32_t _totalSize; /**< データの合計サイズ */
}

@property(assign, readwrite) int32_t totalSize;

/**
 * 初期化します。
 * @param   [in]    seqID   シーケンスID
 * @param   [in]    size    合計サイズ
 */
- (id)initWithSequenceID:(int32_t)seqID totalSize:(int32_t)size;

/**
 * シリアライズされたデータから初期化します。
 * @param   [in]    aDecoder    シリアライズされたデータ
 * @return  自身を返します。
 */
- (id)initWithCoder:(NSCoder*)aDecoder;

/**
 * 内容をシリアライズします。
 * @param   [in]    aCoder  シリアライズしたデータの書き込み先
 */
- (void)encodeWithCoder:(NSCoder*)aCoder;

@end

/**
 * プロセス間通信データの先頭以外のブロックを表します。
 * @since   SKYSEA8.0
 * @author  Morio Tanioku
 * @date    2012/10/11
 */
@interface MessagingNextData : MessagingPacket {
    NSData* _dividedData;   /**< 分割されたデータ */
}

@property(retain, readwrite) NSData* dividedData;

/**
 * 初期化します。
 * @param   [in]    seqID   シーケンスID
 * @param   [in]    data    分割されたデータ
 * @return  自身を返します。
 */
- (id)initWithSequenceID:(int32_t)seqID data:(NSData*)data;

/**
 * シリアライズされたデータから初期化します。
 * @param   [in]    aDecoder    シリアライズされたデータ
 * @return  自身を返します。
 */
- (id)initWithCoder:(NSCoder*)aDecoder;

/**
 * 内容をシリアライズします。
 * @param   [in]    aCoder  シリアライズしたデータの書き込み先
 */
- (void)encodeWithCoder:(NSCoder*)aCoder;

@end

/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */
