/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */

#import <Foundation/Foundation.h>

/**
 * 文字列テーブルを管理するための機能を提供します。
 * @since   SKYSEA8.2
 * @author  Morio Tanioku
 * @date    2013/03/22
 */
@interface StringTable : NSObject {
    NSMutableDictionary*    _identityToStrings;     /**< リソースIDから文字列を検索するための辞書 */
    NSMutableDictionary*    _stringToIdentities;    /**< 文字列からリソースIDを検索するための辞書 */
    uint32_t                _nextResourceID;        /**< 次のリソースID */
}

/**
 * 初期化します。
 * @return  自身を返します。
 */
- (id)init;

/**
 * 文字列を文字列テーブルに登録します。
 * @param   [in]    string  登録したい文字列
 * @return  登録した文字列のリソースIDを返します。stringが登録済みの場合はそのリソースIDを返します。
 */
- (NSNumber*)registerString:(NSString*)string;

/**
 * 指定された文字列を文字列テーブルから削除します。
 * @param   [in]    string  削除したい文字列
 */
- (void)unregisterString:(NSString*)string;

/**
 * 指定されたリソースIDの文字列を文字列テーブルに登録します。
 * @param   [in]    identity    削除したい文字列のリソースID
 */
- (void)unregisterStringWithResourceID:(NSNumber*)identity;

/**
 * 文字列からリソースIDを検索します。
 * @param   [in]    string  検索したい文字列
 * @return  stringに対応するリソースIDを返します。stringが文字列テーブルに存在しない場合はnilを返します。
 */
- (NSNumber*)findWithString:(NSString*)string;

/**
 * リソースIDから文字列を検索します。
 * @param   [in]    identity    検索したいリソースID
 * @return  identityに対応する文字列を返します。identityが文字列テーブルに存在しない場合はnilを返します。
 */
- (NSString*)findWithResourceID:(NSNumber*)identity;

@end

/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */
