/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */

#import <Foundation/Foundation.h>

/**
 * システムに関する情報を扱うための機能を提供します。
 * @since   SKYSEA8.0
 * @author  Morio Tanioku
 * @date    2012/09/04
 */
@interface SystemInfo : NSObject {
    NSString* _hostName;    // ホスト名のキャッシュ
}

/**
 * システムで共有されているインスタンスを取得します。
 * @return  共有されているインスタンスを返します。
 */
+ (SystemInfo*)sharedInfo;

/**
 * コンピューター名を取得します。
 * @return 「システム環境設定」-「共有」で設定されているコンピューター名を返します。
 */
- (NSString*)localizedName;

/**
 * ホスト名を取得します。
 * @return ホスト名
 */
- (NSString *)hostname;

/**
 * システムの経過時間を取得します。
 * @return  経過時間をミリ秒単位で返します。
 */
- (uint64_t)tickCount;

/**
 * Mac OSバージョンを取得します。
 * @return  Mac OSバージョン(10.X.X)
 */
- (NSString*)macOsVersion;

/**
 * Mac OSビルドバージョンを取得します。
 * @return  Mac OSビルドバージョン(13F1911)
 */
- (NSString*)macOsBuildVersion;

/**
 * ハードウェアUUIDを取得します。
 * @return  ハードウェアUUID
 */
- (NSString*)platformUUID;

/**
 * MACアドレス(en0)を取得します。
 * @return  MACアドレス
 */
- (NSString*)macAddressEn0;

/**
 * OS X Snow Leopard(10.6)以降かどうかテストします。
 * @return  OS X Snow Leopard(10.6)以降の場合はYES、未満の場合はNOを返します。
 */
- (Boolean)isSnowLeopardOrLater;

/**
 * OS X lion(10.7)以降かどうかテストします。
 * @return  OS X lion(10.7)以降の場合はYES、未満の場合はNOを返します。
 */
- (Boolean)isLionOrLater;

@end

/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */
