/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */

#import <Foundation/Foundation.h>

/**
 * 要求チャネルのイベントを受け取るためのインターフェースを定義します。
 * @since   SKYSEA8.0
 * @author  Morio Tanioku
 * @date    2012/09/07
 */
@protocol RequestChannelDelegate <NSObject>

/**
 * 要求の処理を委譲します。
 * @param   [in]    request 委譲する要求
 */
- (void)performRequest:(id)request;

/**
 * ワーカースレッドが終了したことを通知します。
 */
- (void)workerFinished;

@end

/**
 * 蓄積された要求を順番に処理するための機能を提供します。
 * @since   SKYSEA8.0
 * @author  Morio Tanioku
 * @date    2012/09/07
 */
@interface RequestChannel : NSObject {
    NSMutableArray* _waitingRequests;       /**< 蓄積されている要求 */
    NSCondition*    _waitingRequestLock;    /**< 要求が追加されたことを知るためのイベント */
    NSMutableArray* _workers;               /**< 要求を実行するためのワーカースレッド */
    id<RequestChannelDelegate>  _delegate;  /**< イベントの通知先 */
}

@property(retain, readwrite) id<RequestChannelDelegate> delegate;

/**
 * 要求の処理を開始します。
 * @param   [in]    numberOfWorkers 作成するワーカースレッド数
 * @return  自身を返します。
 */
- (id)initWithWorkers:(uint32_t)numberOfWorkers;

/**
 * 要求の処理を開始します。
 * @param   [in]    numberOfWorkers 作成するワーカースレッド数
 * @param   [in]    prefix          スレッド名の前置詞
 * @return  自身を返します。
 */
- (id)initWithWorkers:(uint32_t)numberOfWorkers workerName:(NSString*)prefix;

/**
 * 要求の処理を終了します。
 */
- (void)shutdown;

/**
 * 要求を追加します。
 * @param   [in]    request 要求内容
 */
- (void)put:(id)request;

@end

/* Copyright (c)2012 Sky Co., LTD. All rights reserved. */
