//
//  SharedDateFormatter.h
//  CommonUtils
//
//  Created by 丸山 隆夫 on 2014/11/21.
//  Copyright (c) 2014年 Sky Co., LTD. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 * @brief   日時フォーマットのタイプ
 */
enum _DateFormatType {
    DateFormatType_Basic,           // よく使うフォーマット - yyyy/MM/dd HH:mm:ss:SSS
    DateFormatType_DateTime,        // 日時 - yyyy/MM/dd HH:mm:ss
    DateFormatType_Date,            // 年月日 - yyyy/MM/dd
    DateFormatType_Date_NoDelimiter,// 年月日（区切りなし） - yyyyMMdd
    DateFormatType_Date_Hyphen      // 年月日（ハイフン区切り） - yyyy-MM-dd
} typedef DateFormatType;


/**
 * @brief   NSDateFormatterを管理するクラス（シングルトン）
 */
@interface SharedDateFormatter : NSObject {
@private
    NSDictionary* _dateFormat;              // タイプ毎のフォーマット文字列を格納する
    NSMutableDictionary* _dateFormatters;   // NSDateFormatterを格納するDicitonary
}

/**
 * @brief   BasicタイプのNSDateFormatterを返す
 * @return  BasicタイプのNSDateFormatter
 * @sa ------------------------------------------------------------
 * @test    2014/11/21 ta-maruyama SKYSEA10.0 デバイス使用期間機能改善
 */
+ (NSDateFormatter*)sharedDateFormatter;

/**
 * @brief   指定されたタイプのNSDateFormatterを返す
 * @return  NSDateFormatter
 * @sa ------------------------------------------------------------
 * @test    2014/11/21 ta-maruyama SKYSEA10.0 デバイス使用期間機能改善
 */
+ (NSDateFormatter*)sharedDateFormatterWithType:(DateFormatType)type;

@end
